# arch-tag: cd547407-1daf-41ce-a75b-5fb8f5590f33
# Copyright (C) 2004 Canonical Ltd.
#               2004 David Allouche <david@allouche.net>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

"""Test suite
"""

__all__ = [
    # Test framework
    'framework',
    'framework_twisted',
    # Test suites
    'test_coding',
    'test_namespace',
    'test_escaping',
    'test_output',
    'test_arch',
    'test_revlib',
    'test_twisted',
    'test_twisted_arch',
    # Utility
    'test_suite',
    'main',
    ]

import unittest

def my_import(name):
    mod = __import__(name)
    components = name.split('.')
    for comp in components[1:]:
        mod = getattr(mod, comp)
    return mod

def test_suite(limit=()):
    excluded = ('test_suite', 'test_twisted', 'test_twisted_arch')
    suite = unittest.TestSuite()
    if limit:
        for test_name in limit:
            components = test_name.split('.')
            assert len(components) in (1,2)
            module_name = components[0]
            module = my_import('%s.test_%s' % (__name__, module_name))
            module_limit = components[1:]
            suite.addTest(module.test_suite(module_limit))
    else:
        for module_name in __all__:
            if module_name in excluded: continue
            if not module_name.startswith('test_'): continue
            module = my_import('%s.%s' % (__name__, module_name))
            suite.addTest(module.test_suite())
    return suite

def main(argv):
    from arch.tests import framework
    return framework.run_test_suite(argv, test_suite)
