# Copyright (C) 2004 Aaron Bentley
# <aaron.bentley@utoronto.ca>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import sys
import os

sys.path=[os.path.realpath(os.path.dirname(__file__)+"/..")]+sys.path
import pylon
from pylon import errors

import cmdutil
import commands

__docformat__ = "restructuredtext"
__doc__ = "fill-library command"

class FillLibrary(commands.BaseCommand):
    """Copy all library revisions to a single library"""
    def __init__(self):
        self.description = self.__doc__

    def get_completer(self, arg, index):
        return cmdutil.iter_dir_completions(arg)

    def do_command(self, cmdargs):
        parser=self.get_parser()
        (options, args) = parser.parse_args(cmdargs)
        if len(args) != 1:
            raise errors.GetHelp
        if not pylon.is_library_dir(args[0]):
            raise errors.CommandFailedWrapper(errors.NotLibrary(args[0]))
        for revision in arch_compound.iter_all_library_revisions():
            if revision.archive.is_registered():
                cmdutil.chatter("Adding %s" % revision)
                for line in pylon.iter_library_add(revision, args[0]):
                    cmdutil.colorize(line)
            else:
                cmdutil.chatter("Skipping %s" % revision)
        return 0

    def get_parser(self):
        parser = cmdutil.CmdOptionParser("fill-library DIR")
        return parser

    def help(self, parser=None):
        """
        Prints a help message.

        :param parser: If supplied, the parser to use for generating help.  If \
        not supplied, it is retrieved.
        :type parser: cmdutil.CmdOptionParser
        """
        if parser==None:
            parser=self.get_parser()
        parser.print_help()
        print """
This command can be used to copy all library revisions to a particular library,
presumably on a different filesystem.  

This process ensures correct inode signatures.  Unfortunately, most of the
copied revisions will not be hard-linked efficiently.

Limitations in some versions of tla library-add mean that revisions for
unregistered libraries will be skipped.
        """


def add_command(commands):
    commands["fill-library"] = FillLibrary



# arch-tag: 6591f6cc-3d18-4505-8061-ad42d3b28132
