# Copyright (C) 2004 Aaron Bentley
# <aaron.bentley@utoronto.ca>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import sys
import os
import arch
import cmdutil

#ensure that the parent directory is in the path (for epydoc)
sys.path=[os.path.realpath(os.path.dirname(__file__)+"/..")]+sys.path

import commands

__docformat__ = "restructuredtext"
__doc__ = "command template"

class RegisterArchive(commands.BaseCommand):
    """Change an archive location registration"""
    def __init__(self):
        self.description = self.__doc__

#   override get_completer if you want custom completion
#    def get_completer(self, arg, index):
#        return cmdutil.iter_dir_completions(arg)

    def do_command(self, cmdargs):
        parser=self.get_parser()
        (options, args) = parser.parse_args(cmdargs)

        if len(args) == 0 or len(args) > 2:
            raise errors.GetHelp
        if options.delete:
            archive = arch.Archive(args[0])
            if not archive.is_registered():
                raise arch.errors.ArchiveNotRegistered(archive)
            archive.unregister()
            print "%s de-registered." % archive.name
        else:
            if len(args) == 1 and arch.NameParser.is_archive_name(args[0]):
                archive = arch.Archive(args[0])
                cmdutil.ensure_archive_registered(archive)
            else:
                if len(args) == 2:
                    name = args[0]
                    location = args[1]
                else:
                    name = None
                    location = args[0]
                archive = arch.register_archive(name, location)
                print "%s registered." % archive.name


        return 0

    def get_parser(self):
        parser = cmdutil.CmdOptionParser(
          "register-archive [options] LOCATION/NAME")
        parser.add_option("-f", "--force", action="store_true", dest="force",
                          help="Overwrite existing location")
        parser.add_option("-d", "--delete", action="store_true", dest="delete",
                          help="Delete archive registration")
        return parser

    def help(self, parser=None):
        """
        Prints a help message.

        :param parser: If supplied, the parser to use for generating help.  If \
        not supplied, it is retrieved.
        :type parser: cmdutil.CmdOptionParser
        """
        if parser==None:
            parser=self.get_parser()
        parser.print_help()
        print """
Verbose help text goes here.
"""


#This function assigns the command class to a user command name
def add_command(commands):
    commands["nregister-archive"] = RegisterArchive



# arch-tag: 2626da9a-18d2-427e-bb3f-380a080a7522
