# Copyright (C) 2004 Aaron Bentley
# <aaron.bentley@utoronto.ca>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import sys
import os
import shutil

sys.path=[os.path.realpath(os.path.dirname(__file__)+"/..")]+sys.path
import arch

import pylon
from pylon.util import tmpdir
from pylon import errors

import cmdutil
import commands

__docformat__ = "restructuredtext"
__doc__ = "Native show-changeset command"

class ShowChangeset(commands.BaseCommand):
    """Show the changes made by a changeset"""
    def __init__(self):
        self.description = self.__doc__

    def get_completer(self, arg, index):
        iter_r = cmdutil.iter_revision_completions(arg, arch.tree_root("."))
        iter_d = cmdutil.iter_dir_completions(arg)
        return cmdutil.iter_combine([iter_r, iter_d])


    def do_command(self, cmdargs):
        parser=self.get_parser()
        (options, args) = parser.parse_args(cmdargs)
        if len(args) != 1:
            raise errors.GetHelp
        try:
            tree = arch.tree_root(".")
        except:
            tree = None
        try:
            revision = cmdutil.determine_revision_arch(tree, args[0])
            tempdir = tmpdir(os.getcwd())
            dir = tempdir
        except errors.CantDetermineRevision:
            revision = None
            if os.access(args[0], os.X_OK) and os.path.isdir(args[0]):
                dirspec=args[0]
                tempdir = None
            elif os.access(args[0], os.R_OK) and os.path.isfile(args[0]):
                tempdir = tmpdir(os.getcwd())
                dirspec = pylon.util.untar_parent(args[0], tempdir)
                
            else:
                raise
        
        try:
            if revision:
                cmdutil.ensure_archive_registered(revision.archive)
                changeset = revision.get_patch(dir)
            elif dirspec:
                changeset = arch.Changeset(dirspec)
            try:
                munger = pylon.ChangesetMunger(changeset)
                munger.read_indices()

                for line in pylon.iter_changes(munger):
                    cmdutil.colorize(line)
            except errors.InvalidChangeset, e:
                raise errors.CommandFailedWrapper(e)

            if options.diff:
                for line in pylon.diff_iter2(munger.changeset):
                    cmdutil.colorize(line)

        finally:
            if tempdir:
                shutil.rmtree(tempdir)
            
        return 0

    def get_parser(self):
        parser = cmdutil.CmdOptionParser("fai show-changeset REVISION/DIR")
        parser.add_option("-d", "--diff", action="store_true", 
                          dest="diff", help="Show diffs")
        return parser

    def help(self, parser=None):
        """
        Prints a help message.

        :param parser: If supplied, the parser to use for generating help.  If \
        not supplied, it is retrieved.
        :type parser: cmdutil.CmdOptionParser
        """
        if parser==None:
            parser=self.get_parser()
        parser.print_help()


def add_command(commands):
    commands["show-changeset"] = ShowChangeset


# arch-tag: 04abf5e0-b961-4367-9c47-d2d25f8f0ddb
