# Copyright (C) 2004 Aaron Bentley
# <aaron.bentley@utoronto.ca>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import sys
import os

#ensure that the parent directory is in the path (for epydoc)
sys.path=[os.path.realpath(os.path.dirname(__file__)+"/..")]+sys.path

import commands
import cmdutil
import arch
import pylon

__docformat__ = "restructuredtext"
__doc__ = "command template"

class SnapConfig(commands.BaseCommand):
    """Generates a config using the current tree root"""
    def __init__(self):
        self.description = self.__doc__

#   override get_completer if you want custom completion
#    def get_completer(self, arg, index):
#        return cmdutil.iter_dir_completions(arg)
    def get_tree_pairs(self, dir, show_revision=True):
        root = arch.tree_root(dir)
        if show_revision:
            ver_or_rev = str(pylon.tree_latest(root))
        else:
            ver_or_rev = str(root.tree_version)
        dir_string = dir
        if dir_string is not None:
            tree_pairs = [(dir_string, ver_or_rev)]
        else:
            tree_pairs = []
        if dir is not None:
            dir_spec = (dir,)
        else:
            dir_spec = None
        for child_dir in pylon.iter_inventory_filter(None, dir_spec, 
                                                     control_files=True,
                                         categories=(pylon.TreeRootFile,)):
            tree_pairs.extend(self.get_tree_pairs(child_dir.name, 
                                                  show_revision))
        return tree_pairs

    def do_command(self, cmdargs):
        parser=self.get_parser()
        (options, args) = parser.parse_args(cmdargs)

        if len(args) !=0:
            raise errors.GetHelp
        tree_pairs = self.get_tree_pairs(None, 
                                         show_revision=options.revisions)
        max_len = 0
        for dir_string, ver_or_rev in tree_pairs:
            if len(dir_string) > max_len:
                max_len = len(dir_string)
        for dir_string, ver_or_rev in tree_pairs:
            numtabs=(max_len - len(dir_string)+7)/8+1
            tabs = ""
            for i in range(numtabs):
                tabs+="\t"
            print "./%s%s%s" % (dir_string, tabs, ver_or_rev)
        return 0

    def get_parser(self):
        parser = cmdutil.CmdOptionParser("snap-config [options]")
        parser.add_option("--revisions", action="store_true", dest="revisions",
                          help="Use full revisions, not versions")
        return parser

    def help(self, parser=None):
        """
        Prints a help message.

        :param parser: If supplied, the parser to use for generating help.  If \
        not supplied, it is retrieved.
        :type parser: cmdutil.CmdOptionParser
        """
        if parser==None:
            parser=self.get_parser()
        parser.print_help()
        print """
Verbose help text goes here.
"""


#This function assigns the command class to a user command name
def add_command(commands):
    commands["snap-config"] = SnapConfig 

# arch-tag: 83934814-b626-4653-9874-520abef4642e
