# Copyright (C) 2004 Aaron Bentley
# <aaron.bentley@utoronto.ca>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

__docformat__ = "restructuredtext"
__doc__ = "A miscellany of stuff"


class rewind_iterator:
    """A rewindable iterator wrapper"""
    def __init__(self, base_iterator):
        """Initializer.
        
        :param base_iterator: The iterator to make rewindable
        :type base_iterator: Iterable of anything
        """
        self.base_iterator = base_iterator.__iter__()
        self.read_items = []
        self.list_iterator = self.read_items.__iter__()
        self.use_list = True

    def next(self):
        if self.use_list:
            try:
                return self.list_iterator.next()
            except StopIteration:
                self.use_list = False

        item = self.base_iterator.next()
        self.read_items.append(item)
        return item

    def rewind(self):
        """Rewind and start iterating again from the sequence beginning."""
        self.use_list = True
        self.list_iterator = self.read_items.__iter__()

    def __iter__(self):
        return self


def invert_dict(dict):
    newdict = {}
    for (key,value) in dict.iteritems():
        newdict[value] = key
    return newdict


# arch-tag: 9573f21a-15c4-4b9a-9f26-e744b3a58aa5
